@@ -14,16 +14,21 @@
 
 import ConfigParser
 import importlib
-import logging
+
+from oslo.config import cfg
 from pecan import request
+
 from libra.api.library.exp import NotAuthorized
+from libra.openstack.common import log
+
+
+LOG = log.getLogger(__name__)
 
 
 def get_limited_to_project(headers):
     """Return the tenant the request should be limited to."""
     tenant_id = headers.get('X-Tenant-Id')
-    logger = logging.getLogger(__name__)
-    logger.info(
+    LOG.info(
         'Loadbalancers {0} request {1} ({2}) from {3} tenant {4}'.format(
             request.environ.get('REQUEST_METHOD'),
             request.environ.get('PATH_INFO'),
@@ -43,10 +48,9 @@ class AuthDirector(object):
         will direct intentionally unauthenticated requests to the relevant
         controllers. """
 
-    def __init__(self, app, args):
-        self.args = args
+    def __init__(self, app):
         self.unauthed_app = app
-        if not args.disable_keystone:
+        if not cfg.CONF['api']['disable_keystone']:
             self.app = self._install()
         else:
             self.app = app
@@ -61,8 +65,8 @@ class AuthDirector(object):
     def _install(self):
         """Install ACL check on application."""
         config = ConfigParser.SafeConfigParser()
-        config.read([self.args.config])
-        module_details = self.args.keystone_module.split(':')
+        config.read(cfg.CONF['config_file'])
+        module_details = cfg.CONF['api']['keystone_module'].split(':')
         keystone = importlib.import_module(module_details[0])
         auth_class = getattr(keystone, module_details[1])
         return auth_class(self.unauthed_app, config._sections['keystone'])
